import 'package:flutter/material.dart';
import 'package:uplanit_calendar/src/timeline.dart';
import 'package:dotted_line/dotted_line.dart';

class UplanitTimelineView extends StatefulWidget {
  final Function(Timeline) onMarkAsBusy;
  final Function(Timeline) onRemoveBusyTime;
  final List<DateTime> events;
  final bool closed;
  final bool selectable;
  final bool markingAsBusy;
  UplanitTimelineView({
    Key key,
    this.onMarkAsBusy,
    this.onRemoveBusyTime,
    this.events,
    this.closed = false,
    this.selectable = false,
    this.markingAsBusy = false,
  }) : super(key: key);

  @override
  _UplanitTimelineViewState createState() => _UplanitTimelineViewState();
}

class _UplanitTimelineViewState extends State<UplanitTimelineView> {
  bool selected = false;

  List<Timeline> timelines;

  @override
  void initState() {
    super.initState();
    timelines = [
  Timeline(start: '12am', end: '1am', isSelected: true),
  // Timeline(start: '1am', end: '2am', isSelected: false),
  // Timeline(start: '2am', end: '3am', isSelected: true),
  // Timeline(start: '3am', end: '4am', isSelected: false),
  // Timeline(start: '4am', end: '5am', isSelected: false),
  // Timeline(start: '5am', end: '6am', isSelected: false),
  // Timeline(start: '6am', end: '7am', isSelected: false),
  // Timeline(start: '7am', end: '8am', isSelected: true),
  // Timeline(start: '8am', end: '9am', isSelected: false),
  // Timeline(start: '9am', end: '10am', isSelected: false),
  // Timeline(start: '10am', end: '11am', isSelected: true),
  // Timeline(start: '11am', end: '12pm', isSelected: true),
  // Timeline(start: '12pm', end: '1pm', isSelected: false),
  // Timeline(start: '1pm', end: '2pm', isSelected: false),
  // Timeline(start: '2pm', end: '3pm', isSelected: false),
  // Timeline(start: '3pm', end: '4pm', isSelected: false),
  // Timeline(start: '4pm', end: '5pm', isSelected: false),
  // Timeline(start: '5pm', end: '6pm', isSelected: false),
  // Timeline(start: '6pm', end: '7pm', isSelected: false),
  // Timeline(start: '7pm', end: '8pm', isSelected: false),
  // Timeline(start: '8pm', end: '9pm', isSelected: false),
  // Timeline(start: '9pm', end: '10pm', isSelected: false),
  // Timeline(start: '10pm', end: '11pm', isSelected: false),
  // Timeline(start: '11pm', end: '12pm', isSelected: false),
];
  }


  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: 400,
      decoration: BoxDecoration(
        border: Border.all(
          color: Colors.grey,
          width: 1,
        ),
      ),
      child: widget.closed
          ? Container(
              child: Text('Closed',
                  style: TextStyle(
                    fontSize: 16.0,
                    fontWeight: FontWeight.w400,
                  )),

            )
          : SingleChildScrollView(
              child: Padding(
                padding: const EdgeInsets.all(8),
                child: Column(
                  children: timelines == null ? [] : timelines
                      .map((timeline) => Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Padding(
                                padding: const EdgeInsets.only(left: 12),
                                child: Column(
                                  children: [
                                    Text(
                                      '${timeline.start}',
                                      style: TextStyle(fontSize: 12),
                                    ),
                                    SizedBox(height: 4),
                                    InkWell(
                                      onTap: () =>
                                          widget.onMarkAsBusy(timeline),
                                      child: Container(
                                        width: 40,
                                        padding: EdgeInsets.all(4),
                                        decoration: BoxDecoration(
                                          color: Colors.grey.withOpacity(.4),
                                          border: Border.all(
                                            width: 1,
                                            color: Colors.black54,
                                          ),
                                          borderRadius:
                                              BorderRadius.circular(8),
                                        ),
                                        child: widget.markingAsBusy
                                            ? SizedBox(
                                                width: 16,
                                                child:
                                                    CircularProgressIndicator(
                                                  strokeWidth: 5,
                                                  valueColor:
                                                      AlwaysStoppedAnimation<
                                                          Color>(Colors.grey),
                                                ),
                                              )
                                            : Icon(
                                                Icons.business_center_outlined,
                                                size: 16,
                                                color: Colors.black54,
                                              ),
                                      ),
                                    ),
                                  ],
                                ),
                              ),
                              SizedBox(width: 8),
                              Expanded(
                                child: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Container(
                                      width: 280,
                                      padding: const EdgeInsets.all(16),
                                      margin: const EdgeInsets.only(bottom: 4),
                                      decoration: BoxDecoration(
                                        color: timeline.isSelected
                                            ? Color(0xFF7F84A0)
                                            : Colors.transparent,
                                        border: timeline.isSelected
                                            ? Border(
                                                left: BorderSide(
                                                  width: 8,
                                                  color: Color(0xFF161F51),
                                                ),
                                              )
                                            : Border.all(
                                                width: 0,
                                                color: Colors.transparent,
                                              ),
                                      ),
                                      child: Stack(
                                        children: [
                                          Positioned(
                                            top: 8,
                                            left: 8,
                                            child: Column(
                                              mainAxisAlignment:
                                                  MainAxisAlignment.start,
                                              crossAxisAlignment:
                                                  CrossAxisAlignment.start,
                                              children: [
                                                Text(
                                                  'busy',
                                                  style: TextStyle(
                                                    color: Colors.white,
                                                    fontSize: 13,
                                                    fontWeight: FontWeight.bold,
                                                  ),
                                                ),
                                                Text(
                                                  '12am - 1am',
                                                  style: TextStyle(
                                                    color: Colors.white,
                                                    fontSize: 13,
                                                    fontWeight:
                                                        FontWeight.normal,
                                                  ),
                                                )
                                              ],
                                            ),
                                          ),
                                          Positioned(
                                            top: 8,
                                            right: 8,
                                            child: GestureDetector(
                                              onTap: () => widget
                                                  .onRemoveBusyTime(timeline),
                                              child: Container(
                                                child: Icon(
                                                  Icons.cancel,
                                                  size: 16,
                                                  color: Colors.white,
                                                ),
                                              ),
                                            ),
                                          ),
                                        ],
                                      ),
                                    ),
                                    timeline.isSelected
                                        ? Container()
                                        : DottedLine(),
                                    SizedBox(height: 10),
                                    Divider(
                                      color: Colors.black,
                                      thickness: 1,
                                    ),
                                  ],
                                ),
                              ),
                            ],
                          ))
                      .toList(),
                ),
              ),
            ),
    );
  }
}
